| align_chr | R Documentation |
Align text on center text (default is decimal)
align_chr(
x,
accuracy = NULL,
trim_leading_zeros = FALSE,
drop0trailing = FALSE,
add_plusses = FALSE,
padding_character = NULL,
center = ".",
format_integers = FALSE,
side = c("both", "left", "right"),
NA_value = "",
format_numeric_character = FALSE,
...
)
x |
vector (numeric or character) |
accuracy |
number to round to. If NULL, the current default accuracy set with |
trim_leading_zeros |
if TRUE (default), trims leading zeros, otherwise keeps them |
drop0trailing |
Drop trailing zeros |
add_plusses |
if TRUE (default), adds a plus to positive numbers |
padding_character |
character to use for padding, default is |
center |
text on which to align text. Center on decimal by default, but can be any text. |
format_integers |
If TRUE, integers will be formatted with digits |
side |
side on which to make text of equal width |
NA_value |
value to replace NA |
format_numeric_character |
format character variables with numeric content |
... |
additional arguments passed to |
character vector
align_chr(c(1, 10, 100))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.