apa_p_star_note: Make star notes for p-values

View source: R/formatting.R

apa_p_star_noteR Documentation

Make star notes for p-values

Description

Make star notes for p-values

Usage

apa_p_star_note(x = c(0.05, 0.01, 0.001), first_alpha_marginal = FALSE)

Arguments

x

vector of alpha values (p-value thresholds)

first_alpha_marginal

if TRUE, the first alpha value is treated as marginal and gets a dagger instead of a star

Value

character vector

Examples

apa_p_star_note()
apa_p_star_note(x = c(.10, .05, .01, .001), first_alpha_marginal = TRUE)

apa7 documentation built on May 26, 2026, 5:07 p.m.