| apa_parameters | R Documentation |
format model parameters in APA style
apa_parameters(
fit,
predictor_parameters = c("Coefficient", "SE", "Std_Coefficient", "t", "df_error", "p"),
starred = NULL,
bolded = NULL,
column_formats = NULL,
t_with_df = TRUE
)
## S3 method for class 'lm'
apa_parameters(
fit,
predictor_parameters = c("Parameter", "Coefficient", "SE", "Std_Coefficient", "t",
"df_error", "p"),
starred = NA,
bolded = NA,
column_formats = NULL,
t_with_df = TRUE
)
## S3 method for class 'list'
apa_parameters(
fit,
predictor_parameters = c("Parameter", "Coefficient", "SE", "Std_Coefficient", "t",
"df_error", "p"),
starred = NA,
bolded = NA,
column_formats = NULL,
t_with_df = TRUE
)
fit |
model fit object |
predictor_parameters |
predictor parameters to display. If named vector, column names will be vector names |
starred |
columns to star with significant p_values |
bolded |
columns to bold, if significant |
column_formats |
column_formats object to format columns. If NULL, the default column_formats is used. |
t_with_df |
if TRUE, the t column will be displayed with degrees of freedom in parentheses. If FALSE, only the t value is displayed. |
tibble
lm(mpg ~ cyl + wt, data = mtcars) |>
apa_parameters() |>
apa_flextable()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.