| column_formats | R Documentation |
Returns an S7 object that contains a list of column_format objects that can be used to format parameters in APA style.
column_formats(
.data = NULL,
accuracy = NULL,
intercept_text = NULL,
starred_columns = character(0),
variable_labels = character(0),
custom_columns = NULL
)
.data |
list of |
accuracy |
numeric (passed to scales::number) |
intercept_text |
describe intercept |
starred_columns |
which columns get p-value stars |
variable_labels |
named vector of variable names (with vector names as labels). For example, c( |
custom_columns |
named list of column_formats to add or replace existing columns |
column_formats
get_column_namesgetter for column names
get_headersgetter for column headers
get_latexgetter for column latex headers
get_formattersgetter for column formatters
get_header_renamegetter for column names with headers as names
get_header_rename_latexgetter for column names with latex headers as names
get_tibblegetter for tibble with column names, headers, latex headers, and formatters
my_formatter <- column_formats()
my_formatter$Coefficient@formatter <- \(x) round(x, 2)
my_formatter$Coefficient@formatter(2.214)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.