install_apaquarto: Installs the apaquarto extension.

View source: R/apaquarto.R

install_apaquartoR Documentation

Installs the apaquarto extension.

Description

A wrapper for quarto::quarto_add_extension

Usage

install_apaquarto(no_prompt = FALSE, quiet = FALSE, quarto_args = NULL)

Arguments

no_prompt

Do not prompt to confirm approval to download external extension.

quiet

Suppress warning and other messages

quarto_args

Character vector of other quarto CLI arguments to append to the Quarto command executed by this function.

Value

installs the apaquarto Quarto extension

Examples

## Not run: 
install_apaquarto()

## End(Not run)

apa7 documentation built on May 26, 2026, 5:07 p.m.