| make_apaquarto | R Documentation |
A wrapper for shiny::runGitHub Note that running this function will install any missing packages needed to run the app: bsicons, bslib, conflicted, dplyr, fresh, purrr, rclipboard, readr, shiny, shinyWidgets, snakecase, tibble, tidyr, tippy, toastui, yaml
make_apaquarto(launch.browser = TRUE)
launch.browser |
run shiny app in default browser |
Runs a shiny app that creates apaquarto documents
## Not run:
make_apaquarto()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.