star_balance: Prefix text with figure spaces to balance star text

View source: R/formatting.R

star_balanceR Documentation

Prefix text with figure spaces to balance star text

Description

Prefix text with figure spaces to balance star text

Usage

star_balance(x, star = "\\*", superscript = TRUE)

Arguments

x

character vector

star

star text

superscript

Place superscript text if TRUE

Value

character vector

Examples


star_balance(".05\\^\\*\\*\\^")

apa7 documentation built on May 26, 2026, 5:07 p.m.