str_wrap_equal: Like 'stringr::str_wrap', but attempts to create lines of...

View source: R/formatting.R

str_wrap_equalR Documentation

Like stringr::str_wrap, but attempts to create lines of equal width

Description

Like stringr::str_wrap, but attempts to create lines of equal width

Usage

str_wrap_equal(x, max_width = 30L, sep = "\n")

Arguments

x

character

max_width

maximum line width

sep

separation character

Value

character

Examples

str_wrap_equal("This function attempts to split the string into lines with roughly equal width.")

apa7 documentation built on May 26, 2026, 5:07 p.m.