| apa_p_star_note | R Documentation |
Make star notes for p-values
apa_p_star_note(x = c(0.05, 0.01, 0.001), first_alpha_marginal = FALSE)
x |
vector of alpha values (p-value thresholds) |
first_alpha_marginal |
if TRUE, the first alpha value is treated as marginal and gets a dagger instead of a star |
character vector
apa_p_star_note()
apa_p_star_note(x = c(.10, .05, .01, .001), first_alpha_marginal = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.