| install_apaquarto | R Documentation |
A wrapper for quarto::quarto_add_extension
install_apaquarto(no_prompt = FALSE, quiet = FALSE, quarto_args = NULL)
no_prompt |
Do not prompt to confirm approval to download external extension. |
quiet |
Suppress warning and other messages |
quarto_args |
Character vector of other quarto CLI arguments to append to the Quarto command executed by this function. |
installs the apaquarto Quarto extension
## Not run:
install_apaquarto()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.