| num_pad | R Documentation |
Pads text on the left or right so that the width is the same for each element of the vector
num_pad(x, pad_left = TRUE, padding_character = " ", NA_value = "")
x |
vector of text |
pad_left |
if TRUE (default), pads on the left, otherwise pads on the right |
padding_character |
character to use for padding, default is |
NA_value |
value to replace NA |
character vector
num_pad(c("a", "bb"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.