| str_wrap_equal | R Documentation |
stringr::str_wrap, but attempts to create lines of equal widthLike stringr::str_wrap, but attempts to create lines of equal width
str_wrap_equal(x, max_width = 30L, sep = "\n")
x |
character |
max_width |
maximum line width |
sep |
separation character |
character
str_wrap_equal("This function attempts to split the string into lines with roughly equal width.")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.